@@ -31,11 +31,12 @@
  * SUCH DAMAGE.
  */
 
+#include <assert.h>
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <assert.h>
 #include <string.h>
-#include <errno.h>
+#include <unistd.h>
 
 #include "ttyrec.h"
 
@@ -127,3 +128,34 @@ efopen (const char *path, const char *mode)
     return fp;
 }
 
+int
+edup (int oldfd)
+{
+    int fd = dup(oldfd);
+    if (fd == -1) {
+	fprintf(stderr, "%s: dup failed: %s\n", progname, strerror(errno));
+	exit(EXIT_FAILURE);
+    }
+    return fd;
+}
+
+int
+edup2 (int oldfd, int newfd)
+{
+    int fd = dup2(oldfd, newfd);
+    if (fd == -1) {
+	fprintf(stderr, "%s: dup2 failed: %s\n", progname, strerror(errno));
+	exit(EXIT_FAILURE);
+    }
+    return fd;
+}
+
+FILE *
+efdopen (int fd, const char *mode)
+{
+    FILE *fp = fdopen(fd, mode);
+    if (fp == NULL) {
+	fprintf(stderr, "%s: fdopen failed: %s\n", progname, strerror(errno));
+	exit(EXIT_FAILURE);
+    }
+}
