@@ -1,5 +1,7 @@
-#ifndef _TTYPLAYER_H
-#define _TTYPLAYER_H
+#ifndef __TTYREC_H__
+#define __TTYREC_H__
+
+#include "sys/time.h"
 
 typedef struct header {
     struct timeval tv;
